<div align="left">
<img src="docs/assets/head_icon.png" alt="HEADER" width="150" align="left" hspace="15" vspace="0"/>

BEAMZ is an **electromagnetic simulation** package using the FDTD method. It features a **high-level API** for fast prototyping with just a few lines of code as well as an **inverse design module** for topology optimization using the adjoint method with **Jax-based autodiff**. Made for (but not limited to) photonic integrated circuits.
</div>

```bash
pip install beamz
```

![PyPI](https://img.shields.io/pypi/v/beamz?color=black)
![License](https://img.shields.io/github/license/QuentinWach/beamz)
![Stargazers](https://img.shields.io/github/stars/QuentinWach/beamz)
![Last Update](https://img.shields.io/github/last-commit/QuentinWach/beamz)